@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="comment.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class Comment(object):
-    """Comment.
+    """DTO container with a comment.
     """
 
     """
@@ -97,7 +98,7 @@ class Comment(object):
     def link(self):
         """Gets the link of this Comment.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this Comment.  # noqa: E501
         :rtype: WordsApiLink
@@ -108,7 +109,7 @@ class Comment(object):
     def link(self, link):
         """Sets the link of this Comment.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this Comment.  # noqa: E501
         :type: WordsApiLink
@@ -119,7 +120,7 @@ class Comment(object):
     def author(self):
         """Gets the author of this Comment.  # noqa: E501
 
-        Gets or sets returns or sets the author name for a comment.  # noqa: E501
+        Gets or sets the author name for a comment.  # noqa: E501
 
         :return: The author of this Comment.  # noqa: E501
         :rtype: str
@@ -130,7 +131,7 @@ class Comment(object):
     def author(self, author):
         """Sets the author of this Comment.
 
-        Gets or sets returns or sets the author name for a comment.  # noqa: E501
+        Gets or sets the author name for a comment.  # noqa: E501
 
         :param author: The author of this Comment.  # noqa: E501
         :type: str
@@ -141,7 +142,7 @@ class Comment(object):
     def content(self):
         """Gets the content of this Comment.  # noqa: E501
 
-        Gets or sets content of comment.  # noqa: E501
+        Gets or sets the content of the comment.  # noqa: E501
 
         :return: The content of this Comment.  # noqa: E501
         :rtype: StoryChildNodes
@@ -152,7 +153,7 @@ class Comment(object):
     def content(self, content):
         """Sets the content of this Comment.
 
-        Gets or sets content of comment.  # noqa: E501
+        Gets or sets the content of the comment.  # noqa: E501
 
         :param content: The content of this Comment.  # noqa: E501
         :type: StoryChildNodes
@@ -185,7 +186,7 @@ class Comment(object):
     def initial(self):
         """Gets the initial of this Comment.  # noqa: E501
 
-        Gets or sets returns or sets the initials of the user associated with a specific comment.  # noqa: E501
+        Gets or sets the initials of the user associated with a specific comment.  # noqa: E501
 
         :return: The initial of this Comment.  # noqa: E501
         :rtype: str
@@ -196,7 +197,7 @@ class Comment(object):
     def initial(self, initial):
         """Sets the initial of this Comment.
 
-        Gets or sets returns or sets the initials of the user associated with a specific comment.  # noqa: E501
+        Gets or sets the initials of the user associated with a specific comment.  # noqa: E501
 
         :param initial: The initial of this Comment.  # noqa: E501
         :type: str
@@ -207,7 +208,7 @@ class Comment(object):
     def range_end(self):
         """Gets the range_end of this Comment.  # noqa: E501
 
-        Gets or sets link to comment range end node.  # noqa: E501
+        Gets or sets the link to comment range end node.  # noqa: E501
 
         :return: The range_end of this Comment.  # noqa: E501
         :rtype: DocumentPosition
@@ -218,7 +219,7 @@ class Comment(object):
     def range_end(self, range_end):
         """Sets the range_end of this Comment.
 
-        Gets or sets link to comment range end node.  # noqa: E501
+        Gets or sets the link to comment range end node.  # noqa: E501
 
         :param range_end: The range_end of this Comment.  # noqa: E501
         :type: DocumentPosition
@@ -229,7 +230,7 @@ class Comment(object):
     def range_start(self):
         """Gets the range_start of this Comment.  # noqa: E501
 
-        Gets or sets link to comment range start node.  # noqa: E501
+        Gets or sets the link to comment range start node.  # noqa: E501
 
         :return: The range_start of this Comment.  # noqa: E501
         :rtype: DocumentPosition
@@ -240,7 +241,7 @@ class Comment(object):
     def range_start(self, range_start):
         """Sets the range_start of this Comment.
 
-        Gets or sets link to comment range start node.  # noqa: E501
+        Gets or sets the link to comment range start node.  # noqa: E501
 
         :param range_start: The range_start of this Comment.  # noqa: E501
         :type: DocumentPosition
@@ -251,7 +252,7 @@ class Comment(object):
     def text(self):
         """Gets the text of this Comment.  # noqa: E501
 
-        Gets or sets this is a convenience property that allows to easily get or set text of the comment.  # noqa: E501
+        Gets or sets text of the comment.  # noqa: E501
 
         :return: The text of this Comment.  # noqa: E501
         :rtype: str
@@ -262,7 +263,7 @@ class Comment(object):
     def text(self, text):
         """Sets the text of this Comment.
 
-        Gets or sets this is a convenience property that allows to easily get or set text of the comment.  # noqa: E501
+        Gets or sets text of the comment.  # noqa: E501
 
         :param text: The text of this Comment.  # noqa: E501
         :type: str
@@ -276,21 +277,25 @@ class Comment(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -313,6 +318,8 @@ class Comment(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
