@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="compare_data.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -77,7 +78,7 @@ class CompareData(object):
     def author(self):
         """Gets the author of this CompareData.  # noqa: E501
 
-        Gets or sets initials of the author to use for revisions.  # noqa: E501
+        Gets or sets the initials of the author to use for revisions.  # noqa: E501
 
         :return: The author of this CompareData.  # noqa: E501
         :rtype: str
@@ -88,7 +89,7 @@ class CompareData(object):
     def author(self, author):
         """Sets the author of this CompareData.
 
-        Gets or sets initials of the author to use for revisions.  # noqa: E501
+        Gets or sets the initials of the author to use for revisions.  # noqa: E501
 
         :param author: The author of this CompareData.  # noqa: E501
         :type: str
@@ -121,7 +122,7 @@ class CompareData(object):
     def comparing_with_document(self):
         """Gets the comparing_with_document of this CompareData.  # noqa: E501
 
-        Gets or sets path to document to compare at the server.  # noqa: E501
+        Gets or sets the path to document to compare at the server.  # noqa: E501
 
         :return: The comparing_with_document of this CompareData.  # noqa: E501
         :rtype: str
@@ -132,7 +133,7 @@ class CompareData(object):
     def comparing_with_document(self, comparing_with_document):
         """Sets the comparing_with_document of this CompareData.
 
-        Gets or sets path to document to compare at the server.  # noqa: E501
+        Gets or sets the path to document to compare at the server.  # noqa: E501
 
         :param comparing_with_document: The comparing_with_document of this CompareData.  # noqa: E501
         :type: str
@@ -168,21 +169,25 @@ class CompareData(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -205,6 +210,8 @@ class CompareData(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
