@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="document_stat_data.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -82,7 +83,7 @@ class DocumentStatData(object):
     def footnotes_stat_data(self):
         """Gets the footnotes_stat_data of this DocumentStatData.  # noqa: E501
 
-        Gets or sets detailed statistics of footnotes.  # noqa: E501
+        Gets or sets the detailed statistics on footnotes.  # noqa: E501
 
         :return: The footnotes_stat_data of this DocumentStatData.  # noqa: E501
         :rtype: FootnotesStatData
@@ -93,7 +94,7 @@ class DocumentStatData(object):
     def footnotes_stat_data(self, footnotes_stat_data):
         """Sets the footnotes_stat_data of this DocumentStatData.
 
-        Gets or sets detailed statistics of footnotes.  # noqa: E501
+        Gets or sets the detailed statistics on footnotes.  # noqa: E501
 
         :param footnotes_stat_data: The footnotes_stat_data of this DocumentStatData.  # noqa: E501
         :type: FootnotesStatData
@@ -104,7 +105,7 @@ class DocumentStatData(object):
     def page_count(self):
         """Gets the page_count of this DocumentStatData.  # noqa: E501
 
-        Gets or sets total count of pages in the document.  # noqa: E501
+        Gets or sets the total count of pages in the document.  # noqa: E501
 
         :return: The page_count of this DocumentStatData.  # noqa: E501
         :rtype: int
@@ -115,7 +116,7 @@ class DocumentStatData(object):
     def page_count(self, page_count):
         """Sets the page_count of this DocumentStatData.
 
-        Gets or sets total count of pages in the document.  # noqa: E501
+        Gets or sets the total count of pages in the document.  # noqa: E501
 
         :param page_count: The page_count of this DocumentStatData.  # noqa: E501
         :type: int
@@ -126,7 +127,7 @@ class DocumentStatData(object):
     def page_stat_data(self):
         """Gets the page_stat_data of this DocumentStatData.  # noqa: E501
 
-        Gets or sets detailed statistics of all pages.  # noqa: E501
+        Gets or sets the detailed statistics on all pages.  # noqa: E501
 
         :return: The page_stat_data of this DocumentStatData.  # noqa: E501
         :rtype: list[PageStatData]
@@ -137,7 +138,7 @@ class DocumentStatData(object):
     def page_stat_data(self, page_stat_data):
         """Sets the page_stat_data of this DocumentStatData.
 
-        Gets or sets detailed statistics of all pages.  # noqa: E501
+        Gets or sets the detailed statistics on all pages.  # noqa: E501
 
         :param page_stat_data: The page_stat_data of this DocumentStatData.  # noqa: E501
         :type: list[PageStatData]
@@ -148,7 +149,7 @@ class DocumentStatData(object):
     def paragraph_count(self):
         """Gets the paragraph_count of this DocumentStatData.  # noqa: E501
 
-        Gets or sets total count of paragraphs in the document.  # noqa: E501
+        Gets or sets the total count of paragraphs in the document.  # noqa: E501
 
         :return: The paragraph_count of this DocumentStatData.  # noqa: E501
         :rtype: int
@@ -159,7 +160,7 @@ class DocumentStatData(object):
     def paragraph_count(self, paragraph_count):
         """Sets the paragraph_count of this DocumentStatData.
 
-        Gets or sets total count of paragraphs in the document.  # noqa: E501
+        Gets or sets the total count of paragraphs in the document.  # noqa: E501
 
         :param paragraph_count: The paragraph_count of this DocumentStatData.  # noqa: E501
         :type: int
@@ -170,7 +171,7 @@ class DocumentStatData(object):
     def word_count(self):
         """Gets the word_count of this DocumentStatData.  # noqa: E501
 
-        Gets or sets total count of words in the document.  # noqa: E501
+        Gets or sets the total count of words in the document.  # noqa: E501
 
         :return: The word_count of this DocumentStatData.  # noqa: E501
         :rtype: int
@@ -181,7 +182,7 @@ class DocumentStatData(object):
     def word_count(self, word_count):
         """Sets the word_count of this DocumentStatData.
 
-        Gets or sets total count of words in the document.  # noqa: E501
+        Gets or sets the total count of words in the document.  # noqa: E501
 
         :param word_count: The word_count of this DocumentStatData.  # noqa: E501
         :type: int
@@ -195,21 +196,25 @@ class DocumentStatData(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -232,6 +237,8 @@ class DocumentStatData(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
