@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="drawing_object_insert.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -97,7 +98,7 @@ class DrawingObjectInsert(object):
     def height(self):
         """Gets the height of this DrawingObjectInsert.  # noqa: E501
 
-        Gets or sets height of the drawing object in points.  # noqa: E501
+        Gets or sets the height of the DrawingObject in points.  # noqa: E501
 
         :return: The height of this DrawingObjectInsert.  # noqa: E501
         :rtype: float
@@ -108,7 +109,7 @@ class DrawingObjectInsert(object):
     def height(self, height):
         """Sets the height of this DrawingObjectInsert.
 
-        Gets or sets height of the drawing object in points.  # noqa: E501
+        Gets or sets the height of the DrawingObject in points.  # noqa: E501
 
         :param height: The height of this DrawingObjectInsert.  # noqa: E501
         :type: float
@@ -119,7 +120,7 @@ class DrawingObjectInsert(object):
     def left(self):
         """Gets the left of this DrawingObjectInsert.  # noqa: E501
 
-        Gets or sets distance in points from the origin to the left side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the left side of the image.  # noqa: E501
 
         :return: The left of this DrawingObjectInsert.  # noqa: E501
         :rtype: float
@@ -130,7 +131,7 @@ class DrawingObjectInsert(object):
     def left(self, left):
         """Sets the left of this DrawingObjectInsert.
 
-        Gets or sets distance in points from the origin to the left side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the left side of the image.  # noqa: E501
 
         :param left: The left of this DrawingObjectInsert.  # noqa: E501
         :type: float
@@ -141,7 +142,7 @@ class DrawingObjectInsert(object):
     def position(self):
         """Gets the position of this DrawingObjectInsert.  # noqa: E501
 
-        Gets or sets drawing object will be inserted before specified position.  # noqa: E501
+        Gets or sets the position, before which the DrawingObject will be inserted.  # noqa: E501
 
         :return: The position of this DrawingObjectInsert.  # noqa: E501
         :rtype: DocumentPosition
@@ -152,7 +153,7 @@ class DrawingObjectInsert(object):
     def position(self, position):
         """Sets the position of this DrawingObjectInsert.
 
-        Gets or sets drawing object will be inserted before specified position.  # noqa: E501
+        Gets or sets the position, before which the DrawingObject will be inserted.  # noqa: E501
 
         :param position: The position of this DrawingObjectInsert.  # noqa: E501
         :type: DocumentPosition
@@ -163,7 +164,7 @@ class DrawingObjectInsert(object):
     def relative_horizontal_position(self):
         """Gets the relative_horizontal_position of this DrawingObjectInsert.  # noqa: E501
 
-        Gets or sets specifies where the distance to the image is measured from.  # noqa: E501
+        Gets or sets the relative horizontal position, from which the distance to the image is measured.  # noqa: E501
 
         :return: The relative_horizontal_position of this DrawingObjectInsert.  # noqa: E501
         :rtype: str
@@ -174,7 +175,7 @@ class DrawingObjectInsert(object):
     def relative_horizontal_position(self, relative_horizontal_position):
         """Sets the relative_horizontal_position of this DrawingObjectInsert.
 
-        Gets or sets specifies where the distance to the image is measured from.  # noqa: E501
+        Gets or sets the relative horizontal position, from which the distance to the image is measured.  # noqa: E501
 
         :param relative_horizontal_position: The relative_horizontal_position of this DrawingObjectInsert.  # noqa: E501
         :type: str
@@ -193,7 +194,7 @@ class DrawingObjectInsert(object):
     def relative_vertical_position(self):
         """Gets the relative_vertical_position of this DrawingObjectInsert.  # noqa: E501
 
-        Gets or sets specifies where the distance to the image measured from.  # noqa: E501
+        Gets or sets the relative vertical position, from which the distance to the image is measured.  # noqa: E501
 
         :return: The relative_vertical_position of this DrawingObjectInsert.  # noqa: E501
         :rtype: str
@@ -204,7 +205,7 @@ class DrawingObjectInsert(object):
     def relative_vertical_position(self, relative_vertical_position):
         """Sets the relative_vertical_position of this DrawingObjectInsert.
 
-        Gets or sets specifies where the distance to the image measured from.  # noqa: E501
+        Gets or sets the relative vertical position, from which the distance to the image is measured.  # noqa: E501
 
         :param relative_vertical_position: The relative_vertical_position of this DrawingObjectInsert.  # noqa: E501
         :type: str
@@ -223,7 +224,7 @@ class DrawingObjectInsert(object):
     def top(self):
         """Gets the top of this DrawingObjectInsert.  # noqa: E501
 
-        Gets or sets distance in points from the origin to the top side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the top side of the image.  # noqa: E501
 
         :return: The top of this DrawingObjectInsert.  # noqa: E501
         :rtype: float
@@ -234,7 +235,7 @@ class DrawingObjectInsert(object):
     def top(self, top):
         """Sets the top of this DrawingObjectInsert.
 
-        Gets or sets distance in points from the origin to the top side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the top side of the image.  # noqa: E501
 
         :param top: The top of this DrawingObjectInsert.  # noqa: E501
         :type: float
@@ -245,7 +246,7 @@ class DrawingObjectInsert(object):
     def width(self):
         """Gets the width of this DrawingObjectInsert.  # noqa: E501
 
-        Gets or sets width of the drawing objects in points.  # noqa: E501
+        Gets or sets the width of the DrawingObjects in points.  # noqa: E501
 
         :return: The width of this DrawingObjectInsert.  # noqa: E501
         :rtype: float
@@ -256,7 +257,7 @@ class DrawingObjectInsert(object):
     def width(self, width):
         """Sets the width of this DrawingObjectInsert.
 
-        Gets or sets width of the drawing objects in points.  # noqa: E501
+        Gets or sets the width of the DrawingObjects in points.  # noqa: E501
 
         :param width: The width of this DrawingObjectInsert.  # noqa: E501
         :type: float
@@ -267,7 +268,7 @@ class DrawingObjectInsert(object):
     def wrap_type(self):
         """Gets the wrap_type of this DrawingObjectInsert.  # noqa: E501
 
-        Gets or sets specifies how to wrap text around the image.  # noqa: E501
+        Gets or sets the option indicating how to wrap text around the image.  # noqa: E501
 
         :return: The wrap_type of this DrawingObjectInsert.  # noqa: E501
         :rtype: str
@@ -278,7 +279,7 @@ class DrawingObjectInsert(object):
     def wrap_type(self, wrap_type):
         """Sets the wrap_type of this DrawingObjectInsert.
 
-        Gets or sets specifies how to wrap text around the image.  # noqa: E501
+        Gets or sets the option indicating how to wrap text around the image.  # noqa: E501
 
         :param wrap_type: The wrap_type of this DrawingObjectInsert.  # noqa: E501
         :type: str
@@ -300,21 +301,25 @@ class DrawingObjectInsert(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -337,6 +342,8 @@ class DrawingObjectInsert(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
