@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="drawing_object_update.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -92,7 +93,7 @@ class DrawingObjectUpdate(object):
     def height(self):
         """Gets the height of this DrawingObjectUpdate.  # noqa: E501
 
-        Gets or sets height of the drawing object in points.  # noqa: E501
+        Gets or sets the height of the DrawingObject in points.  # noqa: E501
 
         :return: The height of this DrawingObjectUpdate.  # noqa: E501
         :rtype: float
@@ -103,7 +104,7 @@ class DrawingObjectUpdate(object):
     def height(self, height):
         """Sets the height of this DrawingObjectUpdate.
 
-        Gets or sets height of the drawing object in points.  # noqa: E501
+        Gets or sets the height of the DrawingObject in points.  # noqa: E501
 
         :param height: The height of this DrawingObjectUpdate.  # noqa: E501
         :type: float
@@ -114,7 +115,7 @@ class DrawingObjectUpdate(object):
     def left(self):
         """Gets the left of this DrawingObjectUpdate.  # noqa: E501
 
-        Gets or sets distance in points from the origin to the left side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the left side of the image.  # noqa: E501
 
         :return: The left of this DrawingObjectUpdate.  # noqa: E501
         :rtype: float
@@ -125,7 +126,7 @@ class DrawingObjectUpdate(object):
     def left(self, left):
         """Sets the left of this DrawingObjectUpdate.
 
-        Gets or sets distance in points from the origin to the left side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the left side of the image.  # noqa: E501
 
         :param left: The left of this DrawingObjectUpdate.  # noqa: E501
         :type: float
@@ -136,7 +137,7 @@ class DrawingObjectUpdate(object):
     def relative_horizontal_position(self):
         """Gets the relative_horizontal_position of this DrawingObjectUpdate.  # noqa: E501
 
-        Gets or sets specifies where the distance to the image is measured from.  # noqa: E501
+        Gets or sets the relative horizontal position, from which the distance to the image is measured.  # noqa: E501
 
         :return: The relative_horizontal_position of this DrawingObjectUpdate.  # noqa: E501
         :rtype: str
@@ -147,7 +148,7 @@ class DrawingObjectUpdate(object):
     def relative_horizontal_position(self, relative_horizontal_position):
         """Sets the relative_horizontal_position of this DrawingObjectUpdate.
 
-        Gets or sets specifies where the distance to the image is measured from.  # noqa: E501
+        Gets or sets the relative horizontal position, from which the distance to the image is measured.  # noqa: E501
 
         :param relative_horizontal_position: The relative_horizontal_position of this DrawingObjectUpdate.  # noqa: E501
         :type: str
@@ -166,7 +167,7 @@ class DrawingObjectUpdate(object):
     def relative_vertical_position(self):
         """Gets the relative_vertical_position of this DrawingObjectUpdate.  # noqa: E501
 
-        Gets or sets specifies where the distance to the image measured from.  # noqa: E501
+        Gets or sets the relative vertical position, from which the distance to the image measured.  # noqa: E501
 
         :return: The relative_vertical_position of this DrawingObjectUpdate.  # noqa: E501
         :rtype: str
@@ -177,7 +178,7 @@ class DrawingObjectUpdate(object):
     def relative_vertical_position(self, relative_vertical_position):
         """Sets the relative_vertical_position of this DrawingObjectUpdate.
 
-        Gets or sets specifies where the distance to the image measured from.  # noqa: E501
+        Gets or sets the relative vertical position, from which the distance to the image measured.  # noqa: E501
 
         :param relative_vertical_position: The relative_vertical_position of this DrawingObjectUpdate.  # noqa: E501
         :type: str
@@ -196,7 +197,7 @@ class DrawingObjectUpdate(object):
     def top(self):
         """Gets the top of this DrawingObjectUpdate.  # noqa: E501
 
-        Gets or sets distance in points from the origin to the top side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the top side of the image.  # noqa: E501
 
         :return: The top of this DrawingObjectUpdate.  # noqa: E501
         :rtype: float
@@ -207,7 +208,7 @@ class DrawingObjectUpdate(object):
     def top(self, top):
         """Sets the top of this DrawingObjectUpdate.
 
-        Gets or sets distance in points from the origin to the top side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the top side of the image.  # noqa: E501
 
         :param top: The top of this DrawingObjectUpdate.  # noqa: E501
         :type: float
@@ -218,7 +219,7 @@ class DrawingObjectUpdate(object):
     def width(self):
         """Gets the width of this DrawingObjectUpdate.  # noqa: E501
 
-        Gets or sets width of the drawing objects in points.  # noqa: E501
+        Gets or sets the width of the DrawingObjects in points.  # noqa: E501
 
         :return: The width of this DrawingObjectUpdate.  # noqa: E501
         :rtype: float
@@ -229,7 +230,7 @@ class DrawingObjectUpdate(object):
     def width(self, width):
         """Sets the width of this DrawingObjectUpdate.
 
-        Gets or sets width of the drawing objects in points.  # noqa: E501
+        Gets or sets the width of the DrawingObjects in points.  # noqa: E501
 
         :param width: The width of this DrawingObjectUpdate.  # noqa: E501
         :type: float
@@ -240,7 +241,7 @@ class DrawingObjectUpdate(object):
     def wrap_type(self):
         """Gets the wrap_type of this DrawingObjectUpdate.  # noqa: E501
 
-        Gets or sets specifies how to wrap text around the image.  # noqa: E501
+        Gets or sets the option that controls how to wrap text around the image.  # noqa: E501
 
         :return: The wrap_type of this DrawingObjectUpdate.  # noqa: E501
         :rtype: str
@@ -251,7 +252,7 @@ class DrawingObjectUpdate(object):
     def wrap_type(self, wrap_type):
         """Sets the wrap_type of this DrawingObjectUpdate.
 
-        Gets or sets specifies how to wrap text around the image.  # noqa: E501
+        Gets or sets the option that controls how to wrap text around the image.  # noqa: E501
 
         :param wrap_type: The wrap_type of this DrawingObjectUpdate.  # noqa: E501
         :type: str
@@ -273,21 +274,25 @@ class DrawingObjectUpdate(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -310,6 +315,8 @@ class DrawingObjectUpdate(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
