@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="field.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class Field(object):
-    """Field.
+    """DTO container with a field.
     """
 
     """
@@ -82,7 +83,7 @@ class Field(object):
     def link(self):
         """Gets the link of this Field.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this Field.  # noqa: E501
         :rtype: WordsApiLink
@@ -93,7 +94,7 @@ class Field(object):
     def link(self, link):
         """Sets the link of this Field.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this Field.  # noqa: E501
         :type: WordsApiLink
@@ -104,7 +105,7 @@ class Field(object):
     def node_id(self):
         """Gets the node_id of this Field.  # noqa: E501
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :return: The node_id of this Field.  # noqa: E501
         :rtype: str
@@ -115,7 +116,7 @@ class Field(object):
     def node_id(self, node_id):
         """Sets the node_id of this Field.
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :param node_id: The node_id of this Field.  # noqa: E501
         :type: str
@@ -126,7 +127,7 @@ class Field(object):
     def field_code(self):
         """Gets the field_code of this Field.  # noqa: E501
 
-        Gets or sets field code.  # noqa: E501
+        Gets or sets the field code.  # noqa: E501
 
         :return: The field_code of this Field.  # noqa: E501
         :rtype: str
@@ -137,7 +138,7 @@ class Field(object):
     def field_code(self, field_code):
         """Sets the field_code of this Field.
 
-        Gets or sets field code.  # noqa: E501
+        Gets or sets the field code.  # noqa: E501
 
         :param field_code: The field_code of this Field.  # noqa: E501
         :type: str
@@ -148,7 +149,7 @@ class Field(object):
     def locale_id(self):
         """Gets the locale_id of this Field.  # noqa: E501
 
-        Gets or sets LCID of the field.  # noqa: E501
+        Gets or sets the LCID of the field.  # noqa: E501
 
         :return: The locale_id of this Field.  # noqa: E501
         :rtype: str
@@ -159,7 +160,7 @@ class Field(object):
     def locale_id(self, locale_id):
         """Sets the locale_id of this Field.
 
-        Gets or sets LCID of the field.  # noqa: E501
+        Gets or sets the LCID of the field.  # noqa: E501
 
         :param locale_id: The locale_id of this Field.  # noqa: E501
         :type: str
@@ -170,7 +171,7 @@ class Field(object):
     def result(self):
         """Gets the result of this Field.  # noqa: E501
 
-        Gets or sets field result.  # noqa: E501
+        Gets or sets the field result.  # noqa: E501
 
         :return: The result of this Field.  # noqa: E501
         :rtype: str
@@ -181,7 +182,7 @@ class Field(object):
     def result(self, result):
         """Sets the result of this Field.
 
-        Gets or sets field result.  # noqa: E501
+        Gets or sets the field result.  # noqa: E501
 
         :param result: The result of this Field.  # noqa: E501
         :type: str
@@ -195,21 +196,25 @@ class Field(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -232,6 +237,8 @@ class Field(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
