@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="field_names.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -67,7 +68,7 @@ class FieldNames(object):
     def link(self):
         """Gets the link of this FieldNames.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this FieldNames.  # noqa: E501
         :rtype: WordsApiLink
@@ -78,7 +79,7 @@ class FieldNames(object):
     def link(self, link):
         """Sets the link of this FieldNames.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this FieldNames.  # noqa: E501
         :type: WordsApiLink
@@ -89,7 +90,7 @@ class FieldNames(object):
     def names(self):
         """Gets the names of this FieldNames.  # noqa: E501
 
-        Gets or sets collection of fields names.  # noqa: E501
+        Gets or sets the collection of fields names.  # noqa: E501
 
         :return: The names of this FieldNames.  # noqa: E501
         :rtype: list[str]
@@ -100,7 +101,7 @@ class FieldNames(object):
     def names(self, names):
         """Sets the names of this FieldNames.
 
-        Gets or sets collection of fields names.  # noqa: E501
+        Gets or sets the collection of fields names.  # noqa: E501
 
         :param names: The names of this FieldNames.  # noqa: E501
         :type: list[str]
@@ -114,21 +115,25 @@ class FieldNames(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -151,6 +156,8 @@ class FieldNames(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
