@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="footnote_insert.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -77,7 +78,7 @@ class FootnoteInsert(object):
     def footnote_type(self):
         """Gets the footnote_type of this FootnoteInsert.  # noqa: E501
 
-        Gets or sets returns a value that specifies whether this is a footnote or endnote.  # noqa: E501
+        Gets or sets the option, that specifies whether this is a footnote or endnote.  # noqa: E501
 
         :return: The footnote_type of this FootnoteInsert.  # noqa: E501
         :rtype: str
@@ -88,7 +89,7 @@ class FootnoteInsert(object):
     def footnote_type(self, footnote_type):
         """Sets the footnote_type of this FootnoteInsert.
 
-        Gets or sets returns a value that specifies whether this is a footnote or endnote.  # noqa: E501
+        Gets or sets the option, that specifies whether this is a footnote or endnote.  # noqa: E501
 
         :param footnote_type: The footnote_type of this FootnoteInsert.  # noqa: E501
         :type: str
@@ -107,7 +108,7 @@ class FootnoteInsert(object):
     def position(self):
         """Gets the position of this FootnoteInsert.  # noqa: E501
 
-        Gets or sets link to comment range start node.  # noqa: E501
+        Gets or sets the link to comment range start node.  # noqa: E501
 
         :return: The position of this FootnoteInsert.  # noqa: E501
         :rtype: DocumentPosition
@@ -118,7 +119,7 @@ class FootnoteInsert(object):
     def position(self, position):
         """Sets the position of this FootnoteInsert.
 
-        Gets or sets link to comment range start node.  # noqa: E501
+        Gets or sets the link to comment range start node.  # noqa: E501
 
         :param position: The position of this FootnoteInsert.  # noqa: E501
         :type: DocumentPosition
@@ -129,7 +130,7 @@ class FootnoteInsert(object):
     def reference_mark(self):
         """Gets the reference_mark of this FootnoteInsert.  # noqa: E501
 
-        Gets or sets /sets custom reference mark to be used for this footnote. Default value is Empty, meaning auto-numbered footnotes are used.  # noqa: E501
+        Gets or sets the custom reference mark to be used for this footnote. Default value is Empty, meaning auto-numbered footnotes are used.  # noqa: E501
 
         :return: The reference_mark of this FootnoteInsert.  # noqa: E501
         :rtype: str
@@ -140,7 +141,7 @@ class FootnoteInsert(object):
     def reference_mark(self, reference_mark):
         """Sets the reference_mark of this FootnoteInsert.
 
-        Gets or sets /sets custom reference mark to be used for this footnote. Default value is Empty, meaning auto-numbered footnotes are used.  # noqa: E501
+        Gets or sets the custom reference mark to be used for this footnote. Default value is Empty, meaning auto-numbered footnotes are used.  # noqa: E501
 
         :param reference_mark: The reference_mark of this FootnoteInsert.  # noqa: E501
         :type: str
@@ -151,7 +152,7 @@ class FootnoteInsert(object):
     def text(self):
         """Gets the text of this FootnoteInsert.  # noqa: E501
 
-        Gets or sets this is a convenience property that allows to easily get or set text of the footnote.  # noqa: E501
+        Gets or sets text of the footnote.  # noqa: E501
 
         :return: The text of this FootnoteInsert.  # noqa: E501
         :rtype: str
@@ -162,7 +163,7 @@ class FootnoteInsert(object):
     def text(self, text):
         """Sets the text of this FootnoteInsert.
 
-        Gets or sets this is a convenience property that allows to easily get or set text of the footnote.  # noqa: E501
+        Gets or sets text of the footnote.  # noqa: E501
 
         :param text: The text of this FootnoteInsert.  # noqa: E501
         :type: str
@@ -176,21 +177,25 @@ class FootnoteInsert(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -213,6 +218,8 @@ class FootnoteInsert(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
