@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="list_info.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class ListInfo(object):
-    """Represents a single document list.
+    """DTO container with a single document list.
     """
 
     """
@@ -97,7 +98,7 @@ class ListInfo(object):
     def link(self):
         """Gets the link of this ListInfo.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this ListInfo.  # noqa: E501
         :rtype: WordsApiLink
@@ -108,7 +109,7 @@ class ListInfo(object):
     def link(self, link):
         """Sets the link of this ListInfo.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this ListInfo.  # noqa: E501
         :type: WordsApiLink
@@ -119,7 +120,7 @@ class ListInfo(object):
     def is_list_style_definition(self):
         """Gets the is_list_style_definition of this ListInfo.  # noqa: E501
 
-        Gets or sets a value indicating whether returns true if this list is a definition of a list style.  # noqa: E501
+        Gets or sets a value indicating whether this list is a definition of a list style.  # noqa: E501
 
         :return: The is_list_style_definition of this ListInfo.  # noqa: E501
         :rtype: bool
@@ -130,7 +131,7 @@ class ListInfo(object):
     def is_list_style_definition(self, is_list_style_definition):
         """Sets the is_list_style_definition of this ListInfo.
 
-        Gets or sets a value indicating whether returns true if this list is a definition of a list style.  # noqa: E501
+        Gets or sets a value indicating whether this list is a definition of a list style.  # noqa: E501
 
         :param is_list_style_definition: The is_list_style_definition of this ListInfo.  # noqa: E501
         :type: bool
@@ -141,7 +142,7 @@ class ListInfo(object):
     def is_list_style_reference(self):
         """Gets the is_list_style_reference of this ListInfo.  # noqa: E501
 
-        Gets or sets a value indicating whether returns true if this list is a reference to a list style.  # noqa: E501
+        Gets or sets a value indicating whether this list is a reference to a list style.  # noqa: E501
 
         :return: The is_list_style_reference of this ListInfo.  # noqa: E501
         :rtype: bool
@@ -152,7 +153,7 @@ class ListInfo(object):
     def is_list_style_reference(self, is_list_style_reference):
         """Sets the is_list_style_reference of this ListInfo.
 
-        Gets or sets a value indicating whether returns true if this list is a reference to a list style.  # noqa: E501
+        Gets or sets a value indicating whether this list is a reference to a list style.  # noqa: E501
 
         :param is_list_style_reference: The is_list_style_reference of this ListInfo.  # noqa: E501
         :type: bool
@@ -163,7 +164,7 @@ class ListInfo(object):
     def is_multi_level(self):
         """Gets the is_multi_level of this ListInfo.  # noqa: E501
 
-        Gets or sets a value indicating whether returns true when the list contains 9 levels; false when 1 level.  # noqa: E501
+        Gets or sets a value indicating whether the list contains 9 levels; false when 1 level.  # noqa: E501
 
         :return: The is_multi_level of this ListInfo.  # noqa: E501
         :rtype: bool
@@ -174,7 +175,7 @@ class ListInfo(object):
     def is_multi_level(self, is_multi_level):
         """Sets the is_multi_level of this ListInfo.
 
-        Gets or sets a value indicating whether returns true when the list contains 9 levels; false when 1 level.  # noqa: E501
+        Gets or sets a value indicating whether the list contains 9 levels; false when 1 level.  # noqa: E501
 
         :param is_multi_level: The is_multi_level of this ListInfo.  # noqa: E501
         :type: bool
@@ -185,7 +186,7 @@ class ListInfo(object):
     def is_restart_at_each_section(self):
         """Gets the is_restart_at_each_section of this ListInfo.  # noqa: E501
 
-        Gets or sets a value indicating whether specifies whether list should be restarted at each section. Default value is false.  # noqa: E501
+        Gets or sets a value indicating whether list should be restarted at each section. The default value is false.  # noqa: E501
 
         :return: The is_restart_at_each_section of this ListInfo.  # noqa: E501
         :rtype: bool
@@ -196,7 +197,7 @@ class ListInfo(object):
     def is_restart_at_each_section(self, is_restart_at_each_section):
         """Sets the is_restart_at_each_section of this ListInfo.
 
-        Gets or sets a value indicating whether specifies whether list should be restarted at each section. Default value is false.  # noqa: E501
+        Gets or sets a value indicating whether list should be restarted at each section. The default value is false.  # noqa: E501
 
         :param is_restart_at_each_section: The is_restart_at_each_section of this ListInfo.  # noqa: E501
         :type: bool
@@ -276,21 +277,25 @@ class ListInfo(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -313,6 +318,8 @@ class ListInfo(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
