@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="office_math_object.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class OfficeMathObject(object):
-    """OfficeMath object.
+    """DTO container with an OfficeMath object.
     """
 
     """
@@ -87,7 +88,7 @@ class OfficeMathObject(object):
     def link(self):
         """Gets the link of this OfficeMathObject.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this OfficeMathObject.  # noqa: E501
         :rtype: WordsApiLink
@@ -98,7 +99,7 @@ class OfficeMathObject(object):
     def link(self, link):
         """Sets the link of this OfficeMathObject.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this OfficeMathObject.  # noqa: E501
         :type: WordsApiLink
@@ -109,7 +110,7 @@ class OfficeMathObject(object):
     def node_id(self):
         """Gets the node_id of this OfficeMathObject.  # noqa: E501
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :return: The node_id of this OfficeMathObject.  # noqa: E501
         :rtype: str
@@ -120,7 +121,7 @@ class OfficeMathObject(object):
     def node_id(self, node_id):
         """Sets the node_id of this OfficeMathObject.
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :param node_id: The node_id of this OfficeMathObject.  # noqa: E501
         :type: str
@@ -131,7 +132,7 @@ class OfficeMathObject(object):
     def content(self):
         """Gets the content of this OfficeMathObject.  # noqa: E501
 
-        Gets or sets content of footnote.  # noqa: E501
+        Gets or sets the content of a footnote.  # noqa: E501
 
         :return: The content of this OfficeMathObject.  # noqa: E501
         :rtype: StoryChildNodes
@@ -142,7 +143,7 @@ class OfficeMathObject(object):
     def content(self, content):
         """Sets the content of this OfficeMathObject.
 
-        Gets or sets content of footnote.  # noqa: E501
+        Gets or sets the content of a footnote.  # noqa: E501
 
         :param content: The content of this OfficeMathObject.  # noqa: E501
         :type: StoryChildNodes
@@ -153,7 +154,7 @@ class OfficeMathObject(object):
     def display_type(self):
         """Gets the display_type of this OfficeMathObject.  # noqa: E501
 
-        Gets or sets /sets Office Math display format type which represents whether an equation is displayed inline with the text or displayed on its own line.  # noqa: E501
+        Gets or sets the display format type of the OfficeMath object. This display format defines whether an equation is displayed inline with the text or displayed on its own line.  # noqa: E501
 
         :return: The display_type of this OfficeMathObject.  # noqa: E501
         :rtype: str
@@ -164,7 +165,7 @@ class OfficeMathObject(object):
     def display_type(self, display_type):
         """Sets the display_type of this OfficeMathObject.
 
-        Gets or sets /sets Office Math display format type which represents whether an equation is displayed inline with the text or displayed on its own line.  # noqa: E501
+        Gets or sets the display format type of the OfficeMath object. This display format defines whether an equation is displayed inline with the text or displayed on its own line.  # noqa: E501
 
         :param display_type: The display_type of this OfficeMathObject.  # noqa: E501
         :type: str
@@ -183,7 +184,7 @@ class OfficeMathObject(object):
     def justification(self):
         """Gets the justification of this OfficeMathObject.  # noqa: E501
 
-        Gets or sets /sets Office Math justification.  # noqa: E501
+        Gets or sets the justification of the OfficeMath object.  # noqa: E501
 
         :return: The justification of this OfficeMathObject.  # noqa: E501
         :rtype: str
@@ -194,7 +195,7 @@ class OfficeMathObject(object):
     def justification(self, justification):
         """Sets the justification of this OfficeMathObject.
 
-        Gets or sets /sets Office Math justification.  # noqa: E501
+        Gets or sets the justification of the OfficeMath object.  # noqa: E501
 
         :param justification: The justification of this OfficeMathObject.  # noqa: E501
         :type: str
@@ -213,7 +214,7 @@ class OfficeMathObject(object):
     def math_object_type(self):
         """Gets the math_object_type of this OfficeMathObject.  # noqa: E501
 
-        Gets or sets type Aspose.Words.Math.OfficeMath.MathObjectType of this Office Math object.  # noqa: E501
+        Gets or sets the type of the OfficeMath object.  # noqa: E501
 
         :return: The math_object_type of this OfficeMathObject.  # noqa: E501
         :rtype: str
@@ -224,7 +225,7 @@ class OfficeMathObject(object):
     def math_object_type(self, math_object_type):
         """Sets the math_object_type of this OfficeMathObject.
 
-        Gets or sets type Aspose.Words.Math.OfficeMath.MathObjectType of this Office Math object.  # noqa: E501
+        Gets or sets the type of the OfficeMath object.  # noqa: E501
 
         :param math_object_type: The math_object_type of this OfficeMathObject.  # noqa: E501
         :type: str
@@ -246,21 +247,25 @@ class OfficeMathObject(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -283,6 +288,8 @@ class OfficeMathObject(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
