@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="page_stat_data.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -77,7 +78,7 @@ class PageStatData(object):
     def footnotes_stat_data(self):
         """Gets the footnotes_stat_data of this PageStatData.  # noqa: E501
 
-        Gets or sets detailed statistics of footnotes.  # noqa: E501
+        Gets or sets the detailed statistics on the footnotes.  # noqa: E501
 
         :return: The footnotes_stat_data of this PageStatData.  # noqa: E501
         :rtype: FootnotesStatData
@@ -88,7 +89,7 @@ class PageStatData(object):
     def footnotes_stat_data(self, footnotes_stat_data):
         """Sets the footnotes_stat_data of this PageStatData.
 
-        Gets or sets detailed statistics of footnotes.  # noqa: E501
+        Gets or sets the detailed statistics on the footnotes.  # noqa: E501
 
         :param footnotes_stat_data: The footnotes_stat_data of this PageStatData.  # noqa: E501
         :type: FootnotesStatData
@@ -99,7 +100,7 @@ class PageStatData(object):
     def page_number(self):
         """Gets the page_number of this PageStatData.  # noqa: E501
 
-        Gets or sets page number.  # noqa: E501
+        Gets or sets the page number.  # noqa: E501
 
         :return: The page_number of this PageStatData.  # noqa: E501
         :rtype: int
@@ -110,7 +111,7 @@ class PageStatData(object):
     def page_number(self, page_number):
         """Sets the page_number of this PageStatData.
 
-        Gets or sets page number.  # noqa: E501
+        Gets or sets the page number.  # noqa: E501
 
         :param page_number: The page_number of this PageStatData.  # noqa: E501
         :type: int
@@ -121,7 +122,7 @@ class PageStatData(object):
     def paragraph_count(self):
         """Gets the paragraph_count of this PageStatData.  # noqa: E501
 
-        Gets or sets total count of paragraphs in the page.  # noqa: E501
+        Gets or sets the total count of paragraphs in the page.  # noqa: E501
 
         :return: The paragraph_count of this PageStatData.  # noqa: E501
         :rtype: int
@@ -132,7 +133,7 @@ class PageStatData(object):
     def paragraph_count(self, paragraph_count):
         """Sets the paragraph_count of this PageStatData.
 
-        Gets or sets total count of paragraphs in the page.  # noqa: E501
+        Gets or sets the total count of paragraphs in the page.  # noqa: E501
 
         :param paragraph_count: The paragraph_count of this PageStatData.  # noqa: E501
         :type: int
@@ -143,7 +144,7 @@ class PageStatData(object):
     def word_count(self):
         """Gets the word_count of this PageStatData.  # noqa: E501
 
-        Gets or sets total count of words in the page.  # noqa: E501
+        Gets or sets the total count of words in the page.  # noqa: E501
 
         :return: The word_count of this PageStatData.  # noqa: E501
         :rtype: int
@@ -154,7 +155,7 @@ class PageStatData(object):
     def word_count(self, word_count):
         """Sets the word_count of this PageStatData.
 
-        Gets or sets total count of words in the page.  # noqa: E501
+        Gets or sets the total count of words in the page.  # noqa: E501
 
         :param word_count: The word_count of this PageStatData.  # noqa: E501
         :type: int
@@ -168,21 +169,25 @@ class PageStatData(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -205,6 +210,8 @@ class PageStatData(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
