@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="replace_text_parameters.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -148,7 +149,7 @@ class ReplaceTextParameters(object):
     def new_value(self):
         """Gets the new_value of this ReplaceTextParameters.  # noqa: E501
 
-        Gets or sets new text value to replace by.  # noqa: E501
+        Gets or sets the new text value to replace by.  # noqa: E501
 
         :return: The new_value of this ReplaceTextParameters.  # noqa: E501
         :rtype: str
@@ -159,7 +160,7 @@ class ReplaceTextParameters(object):
     def new_value(self, new_value):
         """Sets the new_value of this ReplaceTextParameters.
 
-        Gets or sets new text value to replace by.  # noqa: E501
+        Gets or sets the new text value to replace by.  # noqa: E501
 
         :param new_value: The new_value of this ReplaceTextParameters.  # noqa: E501
         :type: str
@@ -170,7 +171,7 @@ class ReplaceTextParameters(object):
     def old_value(self):
         """Gets the old_value of this ReplaceTextParameters.  # noqa: E501
 
-        Gets or sets old text value (or regex pattern IsOldValueRegex) to replace.  # noqa: E501
+        Gets or sets the old text value (or regex pattern IsOldValueRegex) to replace.  # noqa: E501
 
         :return: The old_value of this ReplaceTextParameters.  # noqa: E501
         :rtype: str
@@ -181,7 +182,7 @@ class ReplaceTextParameters(object):
     def old_value(self, old_value):
         """Sets the old_value of this ReplaceTextParameters.
 
-        Gets or sets old text value (or regex pattern IsOldValueRegex) to replace.  # noqa: E501
+        Gets or sets the old text value (or regex pattern IsOldValueRegex) to replace.  # noqa: E501
 
         :param old_value: The old_value of this ReplaceTextParameters.  # noqa: E501
         :type: str
@@ -195,21 +196,25 @@ class ReplaceTextParameters(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -232,6 +237,8 @@ class ReplaceTextParameters(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
