@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="report_engine_settings.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -77,7 +78,7 @@ class ReportEngineSettings(object):
     def csv_data_load_options(self):
         """Gets the csv_data_load_options of this ReportEngineSettings.  # noqa: E501
 
-        Gets or sets options for parsing CSV data.  # noqa: E501
+        Gets or sets the options for parsing CSV data.  # noqa: E501
 
         :return: The csv_data_load_options of this ReportEngineSettings.  # noqa: E501
         :rtype: CsvDataLoadOptions
@@ -88,7 +89,7 @@ class ReportEngineSettings(object):
     def csv_data_load_options(self, csv_data_load_options):
         """Sets the csv_data_load_options of this ReportEngineSettings.
 
-        Gets or sets options for parsing CSV data.  # noqa: E501
+        Gets or sets the options for parsing CSV data.  # noqa: E501
 
         :param csv_data_load_options: The csv_data_load_options of this ReportEngineSettings.  # noqa: E501
         :type: CsvDataLoadOptions
@@ -99,7 +100,7 @@ class ReportEngineSettings(object):
     def data_source_name(self):
         """Gets the data_source_name of this ReportEngineSettings.  # noqa: E501
 
-        Gets or sets a name to reference the data source object in the template.  # noqa: E501
+        Gets or sets the name to reference the data source object in the template.  # noqa: E501
 
         :return: The data_source_name of this ReportEngineSettings.  # noqa: E501
         :rtype: str
@@ -110,7 +111,7 @@ class ReportEngineSettings(object):
     def data_source_name(self, data_source_name):
         """Sets the data_source_name of this ReportEngineSettings.
 
-        Gets or sets a name to reference the data source object in the template.  # noqa: E501
+        Gets or sets the name to reference the data source object in the template.  # noqa: E501
 
         :param data_source_name: The data_source_name of this ReportEngineSettings.  # noqa: E501
         :type: str
@@ -176,21 +177,25 @@ class ReportEngineSettings(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -213,6 +218,8 @@ class ReportEngineSettings(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
