@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="delete_fields_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,15 +23,19 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class DeleteFieldsRequest(object):
+class DeleteFieldsRequest(BaseRequestObject):
     """
     Request model for delete_fields operation.
     Initializes a new instance.
-    :param name The document name.
-    :param node_path Path to the node, which contains collection of fields.
+    :param name The filename of the input document.
+    :param node_path The path to the node in the document tree.
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
@@ -112,8 +116,11 @@ class DeleteFieldsRequest(object):
             "form_params": form_params,
             "body": body_params,
             "collection_formats": collection_formats,
-            "response_type": None  # noqa: E501
+            "response_type": 'None'  # noqa: E501
         }
 
     def get_response_type(self):
-        return None  # noqa: E501
\ No newline at end of file
+        return 'None'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return None
