@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="get_style_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,15 +23,19 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class GetStyleRequest(object):
+class GetStyleRequest(BaseRequestObject):
     """
     Request model for get_style operation.
     Initializes a new instance.
-    :param name The document name.
-    :param style_name Style name.
+    :param name The filename of the input document.
+    :param style_name The name of the style.
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
@@ -107,4 +111,7 @@ class GetStyleRequest(object):
         }
 
     def get_response_type(self):
-        return 'StyleResponse'  # noqa: E501
\ No newline at end of file
+        return 'StyleResponse'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return self.deserialize(response, StyleResponse, api_client)
