@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="insert_form_field_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,16 +23,20 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class InsertFormFieldRequest(object):
+class InsertFormFieldRequest(BaseRequestObject):
     """
     Request model for insert_form_field operation.
     Initializes a new instance.
-    :param name The document name.
+    :param name The filename of the input document.
     :param form_field From field data.
-    :param node_path Path to the node that contains collection of formfields.
+    :param node_path The path to the node in the document tree.
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
@@ -40,7 +44,7 @@ class InsertFormFieldRequest(object):
     :param dest_file_name Result path of the document after the operation. If this parameter is omitted then result of the operation will be saved as the source document.
     :param revision_author Initials of the author to use for revisions.If you set this parameter and then make some changes to the document programmatically, save the document and later open the document in MS Word you will see these changes as revisions.
     :param revision_date_time The date and time to use for revisions.
-    :param insert_before_node Form field will be inserted before node with index.
+    :param insert_before_node The index of the node. A new form field will be inserted before the node with the specified node Id.
     """
 
     def __init__(self, name, form_field, node_path=None, folder=None, storage=None, load_encoding=None, password=None, dest_file_name=None, revision_author=None, revision_date_time=None, insert_before_node=None):
@@ -131,4 +135,7 @@ class InsertFormFieldRequest(object):
         }
 
     def get_response_type(self):
-        return 'FormFieldResponse'  # noqa: E501
\ No newline at end of file
+        return 'FormFieldResponse'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return self.deserialize(response, FormFieldResponse, api_client)
