@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="optimize_document_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,14 +23,18 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class OptimizeDocumentRequest(object):
+class OptimizeDocumentRequest(BaseRequestObject):
     """
     Request model for optimize_document operation.
     Initializes a new instance.
-    :param name The document name.
+    :param name The filename of the input document.
     :param options The document optimization options.
     :param folder Original document folder.
     :param storage Original document storage.
@@ -117,8 +121,11 @@ class OptimizeDocumentRequest(object):
             "form_params": form_params,
             "body": body_params,
             "collection_formats": collection_formats,
-            "response_type": None  # noqa: E501
+            "response_type": 'None'  # noqa: E501
         }
 
     def get_response_type(self):
-        return None  # noqa: E501
\ No newline at end of file
+        return 'None'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return None
