@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="update_list_level_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,17 +23,21 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class UpdateListLevelRequest(object):
+class UpdateListLevelRequest(BaseRequestObject):
     """
     Request model for update_list_level operation.
     Initializes a new instance.
-    :param name The document name.
+    :param name The filename of the input document.
+    :param list_id The list Id.
+    :param list_level The list level.
     :param list_update List object.
-    :param list_id List unique identifier.
-    :param list_level List level identifier.
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
@@ -43,11 +47,11 @@ class UpdateListLevelRequest(object):
     :param revision_date_time The date and time to use for revisions.
     """
 
-    def __init__(self, name, list_update, list_id, list_level, folder=None, storage=None, load_encoding=None, password=None, dest_file_name=None, revision_author=None, revision_date_time=None):
+    def __init__(self, name, list_id, list_level, list_update, folder=None, storage=None, load_encoding=None, password=None, dest_file_name=None, revision_author=None, revision_date_time=None):
         self.name = name
-        self.list_update = list_update
         self.list_id = list_id
         self.list_level = list_level
+        self.list_update = list_update
         self.folder = folder
         self.storage = storage
         self.load_encoding = load_encoding
@@ -60,15 +64,15 @@ class UpdateListLevelRequest(object):
         # verify the required parameter 'name' is set
         if self.name is None:
             raise ValueError("Missing the required parameter `name` when calling `update_list_level`")  # noqa: E501
-        # verify the required parameter 'list_update' is set
-        if self.list_update is None:
-            raise ValueError("Missing the required parameter `list_update` when calling `update_list_level`")  # noqa: E501
         # verify the required parameter 'list_id' is set
         if self.list_id is None:
             raise ValueError("Missing the required parameter `list_id` when calling `update_list_level`")  # noqa: E501
         # verify the required parameter 'list_level' is set
         if self.list_level is None:
             raise ValueError("Missing the required parameter `list_level` when calling `update_list_level`")  # noqa: E501
+        # verify the required parameter 'list_update' is set
+        if self.list_update is None:
+            raise ValueError("Missing the required parameter `list_update` when calling `update_list_level`")  # noqa: E501
 
         path = '/v4.0/words/{name}/lists/{listId}/listLevels/{listLevel}'
         path_params = {}
@@ -139,4 +143,7 @@ class UpdateListLevelRequest(object):
         }
 
     def get_response_type(self):
-        return 'ListResponse'  # noqa: E501
\ No newline at end of file
+        return 'ListResponse'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return self.deserialize(response, ListResponse, api_client)
