@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="update_style_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,16 +23,20 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class UpdateStyleRequest(object):
+class UpdateStyleRequest(BaseRequestObject):
     """
     Request model for update_style operation.
     Initializes a new instance.
-    :param name The document name.
+    :param name The filename of the input document.
+    :param style_name The name of the style.
     :param style_update Style properties to update.
-    :param style_name Style name.
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
@@ -42,10 +46,10 @@ class UpdateStyleRequest(object):
     :param revision_date_time The date and time to use for revisions.
     """
 
-    def __init__(self, name, style_update, style_name, folder=None, storage=None, load_encoding=None, password=None, dest_file_name=None, revision_author=None, revision_date_time=None):
+    def __init__(self, name, style_name, style_update, folder=None, storage=None, load_encoding=None, password=None, dest_file_name=None, revision_author=None, revision_date_time=None):
         self.name = name
-        self.style_update = style_update
         self.style_name = style_name
+        self.style_update = style_update
         self.folder = folder
         self.storage = storage
         self.load_encoding = load_encoding
@@ -58,12 +62,12 @@ class UpdateStyleRequest(object):
         # verify the required parameter 'name' is set
         if self.name is None:
             raise ValueError("Missing the required parameter `name` when calling `update_style`")  # noqa: E501
-        # verify the required parameter 'style_update' is set
-        if self.style_update is None:
-            raise ValueError("Missing the required parameter `style_update` when calling `update_style`")  # noqa: E501
         # verify the required parameter 'style_name' is set
         if self.style_name is None:
             raise ValueError("Missing the required parameter `style_name` when calling `update_style`")  # noqa: E501
+        # verify the required parameter 'style_update' is set
+        if self.style_update is None:
+            raise ValueError("Missing the required parameter `style_update` when calling `update_style`")  # noqa: E501
 
         path = '/v4.0/words/{name}/styles/{styleName}/update'
         path_params = {}
@@ -130,4 +134,7 @@ class UpdateStyleRequest(object):
         }
 
     def get_response_type(self):
-        return 'StyleResponse'  # noqa: E501
\ No newline at end of file
+        return 'StyleResponse'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return self.deserialize(response, StyleResponse, api_client)
