@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="story_child_nodes.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -62,7 +63,7 @@ class StoryChildNodes(object):
     def child_nodes(self):
         """Gets the child_nodes of this StoryChildNodes.  # noqa: E501
 
-        Gets or sets child nodes.  # noqa: E501
+        Gets or sets the list of child nodes.  # noqa: E501
 
         :return: The child_nodes of this StoryChildNodes.  # noqa: E501
         :rtype: list[NodeLink]
@@ -73,7 +74,7 @@ class StoryChildNodes(object):
     def child_nodes(self, child_nodes):
         """Sets the child_nodes of this StoryChildNodes.
 
-        Gets or sets child nodes.  # noqa: E501
+        Gets or sets the list of child nodes.  # noqa: E501
 
         :param child_nodes: The child_nodes of this StoryChildNodes.  # noqa: E501
         :type: list[NodeLink]
@@ -87,21 +88,25 @@ class StoryChildNodes(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -124,6 +129,8 @@ class StoryChildNodes(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
