@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="table_row_insert.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class TableRowInsert(object):
-    """Table row element.
+    """DTO container with a table row element.
     """
 
     """
@@ -67,7 +68,7 @@ class TableRowInsert(object):
     def columns_count(self):
         """Gets the columns_count of this TableRowInsert.  # noqa: E501
 
-        Gets or sets count of columns. Default is 1.  # noqa: E501
+        Gets or sets the count of columns. The default value is 1.  # noqa: E501
 
         :return: The columns_count of this TableRowInsert.  # noqa: E501
         :rtype: int
@@ -78,7 +79,7 @@ class TableRowInsert(object):
     def columns_count(self, columns_count):
         """Sets the columns_count of this TableRowInsert.
 
-        Gets or sets count of columns. Default is 1.  # noqa: E501
+        Gets or sets the count of columns. The default value is 1.  # noqa: E501
 
         :param columns_count: The columns_count of this TableRowInsert.  # noqa: E501
         :type: int
@@ -114,21 +115,25 @@ class TableRowInsert(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -151,6 +156,8 @@ class TableRowInsert(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
