@@ -38,4 +38,8 @@ from test.api.styles.test_styles import TestStyles
 from test.api.table.test_table import TestTable
 from test.api.table.test_table_border import TestTableBorder
 from test.api.text.test_text import TestText
-from test.api.watermark.test_watermark import TestWatermark
\ No newline at end of file
+from test.api.watermark.test_watermark import TestWatermark
+from test.test_url_encode import TestUrlEncode
+from test.test_readme import TestReadme
+from test.test_batch import TestBatch
+from test.test_examples import TestExamples
\ No newline at end of file
